==> orthanc_0.7.2.orig.tar.gz: Orthanc-0.7.2/OrthancServer/ToDcmtkBridge.cpp <==
/**
 * Orthanc - A Lightweight, RESTful DICOM Store
 * Copyright (C) 2012-2013 Medical Physics Department, CHU of Liege,
 * Belgium
 *
 * This program is free software: you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * In addition, as a special exception, the copyright holders of this
 * program give permission to link the code of its release with the
 * OpenSSL project's "OpenSSL" library (or with modified versions of it
 * that use the same license as the "OpenSSL" library), and distribute
 * the linked executables. You must obey the GNU General Public License
 * in all respects for all of the code used other than "OpenSSL". If you
 * modify file(s) with this exception, you may extend this exception to
 * your version of the file(s), but you are not obligated to do so. If
 * you do not wish to do so, delete this exception statement from your
 * version. If you delete this exception statement from all source files
 * in the program, then also delete it here.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 **/


#include "ToDcmtkBridge.h"

#include <memory>
#include <dcmtk/dcmnet/diutil.h>


namespace Orthanc
{
  DcmTagKey ToDcmtkBridge::Convert(const DicomTag& tag)
  {
    return DcmTagKey(tag.GetGroup(), tag.GetElement());
  }


  DcmDataset* ToDcmtkBridge::Convert(const DicomMap& map)
  {
    std::auto_ptr<DcmDataset> result(new DcmDataset);

    for (DicomMap::Map::const_iterator 
           it = map.map_.begin(); it != map.map_.end(); ++it)
    {
      std::string s = it->second->AsString();
      DU_putStringDOElement(result.get(), Convert(it->first), s.c_str());
    }

    return result.release();
  }
}

==> orthanc_1.0.0+dfsg.orig.tar.gz: Orthanc-1.0.0/OrthancServer/ToDcmtkBridge.cpp <==
/**
 * Orthanc - A Lightweight, RESTful DICOM Store
 * Copyright (C) 2012-2015 Sebastien Jodogne, Medical Physics
 * Department, University Hospital of Liege, Belgium
 *
 * This program is free software: you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation, either version 3 of the
 * License, or (at your option) any later version.
 *
 * In addition, as a special exception, the copyright holders of this
 * program give permission to link the code of its release with the
 * OpenSSL project's "OpenSSL" library (or with modified versions of it
 * that use the same license as the "OpenSSL" library), and distribute
 * the linked executables. You must obey the GNU General Public License
 * in all respects for all of the code used other than "OpenSSL". If you
 * modify file(s) with this exception, you may extend this exception to
 * your version of the file(s), but you are not obligated to do so. If
 * you do not wish to do so, delete this exception statement from your
 * version. If you delete this exception statement from all source files
 * in the program, then also delete it here.
 * 
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 **/


#include "PrecompiledHeadersServer.h"
#include "ToDcmtkBridge.h"

#include <memory>
#include <dcmtk/dcmnet/diutil.h>


namespace Orthanc
{
  DcmTagKey ToDcmtkBridge::Convert(const DicomTag& tag)
  {
    return DcmTagKey(tag.GetGroup(), tag.GetElement());
  }


  DcmDataset* ToDcmtkBridge::Convert(const DicomMap& map)
  {
    std::auto_ptr<DcmDataset> result(new DcmDataset);

    for (DicomMap::Map::const_iterator 
           it = map.map_.begin(); it != map.map_.end(); ++it)
    {
      if (!it->second->IsNull())
      {
        std::string s = it->second->GetContent();
        DU_putStringDOElement(result.get(), Convert(it->first), s.c_str());
      }
    }

    return result.release();
  }
}
